@@ -14,7 +14,7 @@ use Module::Load   qw( load );
 use Module::Loaded qw( is_loaded );
 use POSIX          qw( strftime tzset );
 
-our $VERSION = '4.1';
+our $VERSION = '4.2';
 
 # Default for Handling Parsing
 our $DateParsing     = 1;
@@ -23,6 +23,7 @@ our $EpochCreate     = 1;
 our $NormalizeToUTC  = 0;
 our $OutputTimeZone  = 0;
 our $IgnoreTimeZones = 0;
+our $HiResFmt        = '%0.6f';
 
 our $ExtractProgram  = 1;
 our $PruneRaw        = 0;
@@ -201,8 +202,12 @@ sub parse_syslog_line {
                 $msg{epoch} = HTTP::Date::str2time($msg{datetime_raw});
 
                 # Format accordingly, keep highest resolution we can
-                my $diff   = ($msg{epoch} - int($msg{epoch}));
-                my $hires  = $diff > 0 ? substr(sprintf('%0.6f', $diff),1) : '';
+                my $diff  = ($msg{epoch} - int($msg{epoch}));
+                my $hires = '';
+                if( $diff ) {
+                    $msg{epoch} = sprintf $HiResFmt, $msg{epoch};
+                    $hires      = substr(sprintf($HiResFmt,$diff),1);
+                }
                 my $tm_fmt = '%FT%T' . $hires . ( $OutputTimeZone ? ($SYSLOG_TIMEZONE eq 'UTC' ? 'Z' : '%z') : '' );
 
                 # Set the Date Strings
@@ -363,16 +368,11 @@ sub preamble_facility {
 sub set_syslog_timezone {
     my ( $tz_name ) = @_;
 
-    if( defined $tz_name && (!exists $ENV{TZ} || $tz_name ne $ENV{TZ}) ) {
+    if( defined $tz_name && length $tz_name ) {
         $ENV{TZ} = $SYSLOG_TIMEZONE = $tz_name;
         tzset();
+        # Output Timezones
         $OutputTimeZone = 1;
-        # Output some useful debug information
-        printf("set_syslog_timezone('%s') results in a timezone of '%s' with offset: %s\n",
-                $tz_name,
-                strftime('%Z', localtime),
-                strftime('%z', localtime),
-            ) if $ENV{DEBUG_PARSE_SYSLOG_LINE};
     }
 
     return $SYSLOG_TIMEZONE;
@@ -403,7 +403,7 @@ Parse::Syslog::Line - Simple syslog line parser
 
 =head1 VERSION
 
-version 4.1
+version 4.2
 
 =head1 SYNOPSIS
 
@@ -481,8 +481,8 @@ Usage:
 
 =head2 DateParsing
 
-If this variable is set to 0 raw date will not be parsed further into components (datetime_str date time epoch).
-Default is 1 (parsing enabled).
+If this variable is set to 0 raw date will not be parsed further into
+components (datetime_str date time epoch).  Default is 1 (parsing enabled).
 
 Usage:
 
@@ -537,9 +537,16 @@ in your wanted format.
 
 B<NOTE>: No further date processing will be done, you're on your own here.
 
+=head2 HiResFmt
+
+Default is C<%0.6f>, or microsecond resolution.  This variable only comes into
+play when the syslog date string contains a high resolution timestamp.  It
+defaults to using microsecond resolution.
+
 =head2 PruneRaw
 
-This variable defaults to 0, set to 1 to delete all keys in the return hash ending in "_raw"
+This variable defaults to 0, set to 1 to delete all keys in the return hash
+ending in "_raw"
 
 Usage:
 
@@ -547,7 +554,8 @@ Usage:
 
 =head2 PruneEmpty
 
-This variable defaults to 0, set to 1 to delete all keys in the return hash which are undefined.
+This variable defaults to 0, set to 1 to delete all keys in the return hash
+which are undefined.
 
 Usage:
 
